==> sharry-jira-tool-0.1.8.tar.gz: sharry-jira-tool-0.1.8/src/jira_tool/sprint_schedule.py <==
import json

__all__ = ['SprintScheduleStore']


class SprintScheduleStore():
    @classmethod
    def __init__(self) -> None:
        self.store: list[tuple] = []

    @classmethod
    def load(self, content: str):
        raw_data = json.loads(content)

        priority = 0
        sprints = []
        for item in raw_data:
            for key, value in item.items():
                if key.lower() in 'priority':
                    priority = value
                if key.lower() in 'sprints':
                    for sprint in value:
                        if len(sprint) > 0:
                            sprints.append(sprint)

            for sprint in sprints:
                self.store.append((sprint, priority))
            sprints.clear()
            priority = 0

    @classmethod
    def load_file(self, file_path: str):
        schedule_file = open(file=file_path, mode='r')
        raw_data = json.load(schedule_file)

        priority = 0
        sprints = []
        for item in raw_data:
            for key, value in item.items():
                if key.lower() in 'priority':
                    priority = value
                if key.lower() in 'sprints':
                    for sprint in value:
                        if len(sprint) > 0:
                            sprints.append(sprint)

            for sprint in sprints:
                self.store.append((sprint, priority))
            sprints.clear()
            priority = 0

        schedule_file.close()

    @classmethod
    def get_priority(self, sprint: str) -> int:
        for item in self.store:
            if sprint.upper() in item[0].upper():
                return item[1]
        return 0

    @classmethod
    def total_count(self):
        return len(self.store)

==> sharry-jira-tool-0.1.12.tar.gz: sharry-jira-tool-0.1.12/src/jira_tool/sprint_schedule.py <==
import json

__all__ = ["SprintScheduleStore"]


class SprintScheduleStore:
    def __init__(self) -> None:
        self.store: list[tuple] = []

    def load(self, content: str):
        raw_data = json.loads(content)

        priority = 0
        sprints = []
        for item in raw_data:
            for key, value in item.items():
                if key.lower() in "priority":
                    priority = value
                if key.lower() in "sprints":
                    for sprint in value:
                        if len(sprint) > 0:
                            sprints.append(sprint)

            for sprint in sprints:
                self.store.append((sprint, priority))
            sprints.clear()
            priority = 0

    def load_file(self, file_path: str):
        schedule_file = open(file=file_path, mode="r")
        raw_data = json.load(schedule_file)

        priority = 0
        sprints = []
        for item in raw_data:
            for key, value in item.items():
                if key.lower() in "priority":
                    priority = value
                if key.lower() in "sprints":
                    for sprint in value:
                        if len(sprint) > 0:
                            sprints.append(sprint)

            for sprint in sprints:
                self.store.append((sprint, priority))
            sprints.clear()
            priority = 0

        schedule_file.close()

    def get_priority(self, sprint: str) -> int:
        for item in self.store:
            if sprint.upper() in item[0].upper():
                return item[1]
        return 0

    def total_count(self):
        return len(self.store)
